package test;

import javax.jms.*;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import java.io.Serializable;
import java.util.Properties;

public class HQProducer {
    private Session session_;
    private MessageProducer messageProducer_;

    public HQProducer() throws NamingException, JMSException {
        Properties p = new Properties();
        p.put(javax.naming.Context.INITIAL_CONTEXT_FACTORY,
                "org.jnp.interfaces.NamingContextFactory");
        p.put(javax.naming.Context.URL_PKG_PREFIXES,
                "org.jboss.naming:org.jnp.interfaces");
        p.put(javax.naming.Context.PROVIDER_URL, "jnp://localhost:2009");
        InitialContext initialContext = new InitialContext(p);
        ConnectionFactory connectionFactory = (ConnectionFactory) initialContext.lookup("/ConnectionFactory");
        Connection connection = connectionFactory.createConnection();
        session_ = connection.createSession(false, Session.CLIENT_ACKNOWLEDGE);

        Queue testQueue = (Queue) initialContext.lookup("queue/testQueue");

        messageProducer_ = session_.createProducer(testQueue);
        messageProducer_.setDeliveryMode(DeliveryMode.NON_PERSISTENT);
        connection.start();
    }

    public void sendMessage(Serializable message) throws JMSException {
        ObjectMessage objectMessage = session_.createObjectMessage(message);
        messageProducer_.send(objectMessage);
    }

    public static void main(String[] args) throws Exception {
        HQProducer jmsSender = new HQProducer();
        int count = 0;
        while (true) {
            try {
                ++count;
                System.out.println("Sending message..." + count);
                jmsSender.sendMessage("msg: " + count);
            } catch (JMSException ex) {
                ex.printStackTrace();
            } catch (Exception e) {
                System.out.println(e);
                e.printStackTrace();
            } finally {
                Thread.sleep(30000);
            }
        }
    }

}
